<?php
/**
 * @version		1.0.5
 * @package		Joomla
 * @subpackage	Edocman
 * @author  Tuan Pham Ngoc
 * @copyright	Copyright (C) 2011 Ossolution Team
 * @license		GNU/GPL, see LICENSE.php
 */

// No direct access
defined('_JEXEC') or die;

/**
 * document Table class
 */
class EdocmanTabledocument extends JTable
{
	/**
	 * Constructor
	 *
	 * @param JDatabase A database connector object
	 */
	public function __construct(&$db)
	{
		parent::__construct('#__edocman_documents', 'id', $db);
	}

	/**
	 * Overloaded bind function to pre-process the params.
	 *
	 * @param	array		Named array
	 * @return	null|string	null is operation was satisfactory, otherwise returns an error
	 * @see		JTable:bind
	 * @since	1.5
	 */
	public function bind($array, $ignore = '')
	{	    				
	    // Bind the rules.
		if (isset($array['rules']) && is_array($array['rules'])) {
			$rules = new JRules($array['rules']);
			$this->setRules($rules);
		}
								
		return parent::bind($array, $ignore);
	}
    /**
     * Method to return the name to use for asset table
     * @return string
     * @since 11.1
     */
    protected function _getAssetName()
	{			    
		return 'com_edocman.document.'.(int) $this->id;
	}	
	/**
	 * Method to return the title to use for the asset table.
	 *
	 * @return  string
	 *
	 * @since   11.1
	 */
	protected function _getAssetTitle()
	{
		return $this->title;
	}

	/**
	 * Get the parent asset id for the record
	 *
	 * @param   JTable   $table  A JTable object for the asset parent.
	 * @param   integer  $id     The id for the asset
	 *
	 * @return  integer  The id of the asset's parent
	 *
	 * @since   11.1
	 */
	public function _getAssetParentId($table = null, $id = null)
	{	    
		// Initialise variables.
		$assetId = null;
		$db		= JFactory::getDbo() ;
		$categoryId = (int) $_POST['jform']['category_id'] ;
				
		// This is a category under a category.
		if ($categoryId) {		
			$query = $db->getQuery(true);
			$query->select('asset_id');
			$query->from('#__edocman_categories AS a');			
			$query->where('a.id = '.(int) $categoryId);						
			// Get the asset id from the database.
			$db->setQuery($query);						
			$assetId = (int) $db->loadResult() ;					
		}
		// This is a category that needs to parent with the extension.
		elseif ($assetId === null) {
			// Build the query to get the asset id for the parent category.
			$query	= $db->getQuery(true);
			$query->select('id');
			$query->from('#__assets');
			$query->where('name = '.$db->quote('com_edocman'));

			// Get the asset id from the database.
			$db->setQuery($query);			
			$assetId = (int) $db->loadResult() ;			
		}
        
		// Return the asset id.
		if ($assetId) {
			return $assetId;
		} else {
			return parent::_getAssetParentId($table, $id);
		}
	}	   
    /**
     * Store the information into database
     * @see JTable::store()
     */
    public function store($updateNulls = false)
	{
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();
		$categoryId = (int) $_POST['jform']['category_id'] ;
		
		if ($this->id) {
			// Existing Document
			$this->modified_time	= $date->toMySQL();
			$this->modified_user_id	= $user->get('id');
		} else {
			// New Document
			//prise en compte de la date rentrer
			if($this->created_time == "")
			{
				$this->created_time		= $date->toMySQL();
			}
			$this->created_user_id	= $user->get('id');
			$db = JFactory::getDbo() ;		
			$sql = 'SELECT MAX(ordering) FROM #__edocman_documents AS a INNER JOIN #__edocman_document_category AS b ON a.id = b.document_id WHERE b.category_id='.$categoryId ;
			$db->setQuery($sql);
			$this->ordering = (int) $db->loadResult() + 1 ;
		}
				
				
				
		$this->alias = JApplication::stringURLSafe($this->title);
		
		
		//Call parent to store the data
		$ret = parent::store($updateNulls);
							
		if ($categoryId) {
		    $db = & JFactory::getDbo() ;
		    $sql = 'DELETE FROM #__edocman_document_category WHERE document_id='.$this->id ;
		    $db->setQuery($sql) ;
		    $db->query();
		    $sql = "INSERT INTO #__edocman_document_category(category_id, document_id) VALUES($categoryId, $this->id)";
		    $db->setQuery($sql) ;
		    $db->query();
		}
		return $ret ;
	} 
	/**
     * Override delete function
     * @see JTable::delete()
     */
	function delete($pk) 
	{
		//dumpMessage("fonction delete !");
		
		//rcupration de la bdd
		$db = & JFactory::getDbo();
		
		/***supprimer le fichier associ au document***/
	    //rcupration de la configuration Edocman
	    $config = EdocmanHelper::getConfig();
	    
	    //slection du chemin du fichier (rpertoire+nom)
		$sql = 'SELECT `filename` FROM #__edocman_documents WHERE id = '.$pk;
		$db->setQuery($sql);
	    
		//rcupration du chemin de la configuration
		$rootDir = $config->documents_path;
		
		//xcution de la requte
	   	$filename = $db->loadResult();
	    $pathfilename = $rootDir."/".$filename;
	    
	    //dump($pathfilename, 'pathfilename');
	    
	    //suppression du fichier, si il existe
	    if(JFile::exists($pathfilename))
	    {
	    	JFile::delete($pathfilename);
	    }
	    /*********************************************/
	        	    	    	    	  
	    //Delete from relative table
	    $sql = 'DELETE FROM #__edocman_document_category WHERE document_id='.$pk;
	    $db->setQuery($sql) ;
	    $db->query();
	    
	    //Check if the asset id for this record
	    $sql = 'SELECT asset_id FROM #__edocman_documents WHERE id='.$pk;
	    $db->setQuery($sql) ;
	    $assetId = $db->loadResult() ;
	    if($assetId)		    	    	    	    	    	    
	    	return parent::delete($pk);
	    else	    	
	    {
	    	$sql = 'DELETE FROM #__edocman_documents WHERE id='.$pk;
	    	$db->setQuery($sql);
	    	$db->query();
	    	return true;
	    }	
	}					
}
